@@ -3,6 +3,7 @@ from functools import reduce
 
 import numpy as np
 
+
 class Model:
     TIME = 'time'
 
@@ -33,8 +34,6 @@ class Model:
         self.time = self.state(0.0)
         self.der(self.TIME, lambda: 1.0)
 
-
-
     def _new_signal(self, name):
         assert name not in self.signals.keys(), "Signal already defined."
         self.signals[name] = []
@@ -137,6 +136,7 @@ class Model:
     Sets every state to its initial value (provided at the constructor) and clears every signal to its initial value (or empty).
     If you want different initial values, then set them after calling this function.
     """
+
     def reset(self):
         assert not self._under_construction, "Under construction."
 
@@ -152,6 +152,7 @@ class Model:
     """
     Ensures that every signal has a single initial value, or is empty.
     """
+
     def assert_initialized(self):
 
         def _assert_initialized(s):
@@ -311,9 +312,9 @@ class Model:
     def _delayed_signal_value(self, name, d):
         assert name in self.signals.keys(), "Name must be a signal."
         t = self.time()
-        ts = max(0, t+d)  # if -d goes beyond, we set ts=0
+        ts = max(0, t + d)  # if -d goes beyond, we set ts=0
         idx = self._earliest_time(ts)
-        assert idx <= len(self.signals[name])-1, "idx lies within the array domain."
+        assert idx <= len(self.signals[name]) - 1, "idx lies within the array domain."
         value = self.signals[name][idx]
         return value
 
@@ -323,6 +324,7 @@ class Model:
         [0,1,2,3,4] , 1.2 -> 1
         [0,1,2,3,4] , 4.2 -> 4
     """
+
     def _earliest_time(self, t):
         ts = self.signals['time']
         return self._find_sup(t, ts)
@@ -385,7 +387,7 @@ class Model:
 
         res_models = [f_models(m) for m in self._models]
         total = [np.array(res)] + res_models
-        total_flat = reduce(lambda a, b: np.concatenate(a,b), total)
+        total_flat = reduce(lambda a, b: np.concatenate(a, b), total)
 
         num = self.nsignals()
         assert len(total_flat) == num, "Flatten worked."
@@ -436,12 +438,13 @@ class Model:
 
     @staticmethod
     def _find_sup(t, ts):
-        assert(len(ts) > 0)
+        assert (len(ts) > 0)
         idx = len(ts) - 1  # Start at the end
         while ts[idx] > t and idx > 0:
             idx -= 1
-        assert (idx == len(ts) - 1 or idx == 0 or (ts[idx] <= t and ts[idx + 1] > t)), "Idx lies within the correct domain."
-        assert 0 <= idx <= len(ts)-1, "Idx lies within the correct domain."
+        assert (idx == len(ts) - 1 or idx == 0 or (
+                    ts[idx] <= t and ts[idx + 1] > t)), "Idx lies within the correct domain."
+        assert 0 <= idx <= len(ts) - 1, "Idx lies within the correct domain."
         return idx
 
     def discrete_step(self):
